@@ -6,12 +6,8 @@ You can use `simple_receive.py` (or `complete_receive.py`) to receive the
 message sent.
 
 """
-from __future__ import with_statement
-
 import eventlet
 
-from Queue import Empty
-
 from kombu import Connection
 
 eventlet.monkey_patch()
@@ -34,7 +30,7 @@ def wait_many(timeout=1):
             while True:
                 try:
                     message = queue.get(block=False, timeout=timeout)
-                except Empty:
+                except queue.Empty:
                     break
                 else:
                     message.ack()
