@@ -8,6 +8,7 @@ Exchange and Queue declarations.
 from __future__ import absolute_import
 
 from .abstract import MaybeChannelBound
+from .exceptions import ContentDisallowed
 from .serialization import prepare_accept_content
 
 TRANSIENT_DELIVERY_MODE = 1
@@ -15,7 +16,7 @@ PERSISTENT_DELIVERY_MODE = 2
 DELIVERY_MODES = {'transient': TRANSIENT_DELIVERY_MODE,
                   'persistent': PERSISTENT_DELIVERY_MODE}
 
-__all__ = ['Exchange', 'Queue']
+__all__ = ['Exchange', 'Queue', 'binding']
 
 
 def pretty_bindings(bindings):
@@ -39,7 +40,12 @@ class Exchange(MaybeChannelBound):
 
     .. attribute:: type
 
-        AMQP defines four default exchange types (routing algorithms) that
+        *This description of AMQP exchange types was shamelessly stolen
+        from the blog post `AMQP in 10 minutes: Part 4`_ by
+        Rajith Attapattu. Reading this article is recommended if you're
+        new to amqp.*
+
+        "AMQP defines four default exchange types (routing algorithms) that
         covers most of the common messaging use cases. An AMQP broker can
         also define additional exchange types, so see your broker
         manual for more information about available exchange types.
@@ -73,9 +79,6 @@ class Exchange(MaybeChannelBound):
 
                 :attr:`arguments` is used to specify the arguments.
 
-            This description of AMQP exchange types was shamelessly stolen
-            from the blog post `AMQP in 10 minutes: Part 4`_ by
-            Rajith Attapattu. This article is recommended reading.
 
             .. _`AMQP in 10 minutes: Part 4`:
                 http://bit.ly/amqp-exchange-types
@@ -261,6 +264,9 @@ class Exchange(MaybeChannelBound):
                                             if_unused=if_unused,
                                             nowait=nowait)
 
+    def binding(self, routing_key='', arguments=None, unbind_arguments=None):
+        return binding(self, routing_key, arguments, unbind_arguments)
+
     def __eq__(self, other):
         if isinstance(other, Exchange):
             return (self.name == other.name and
@@ -269,7 +275,10 @@ class Exchange(MaybeChannelBound):
                     self.durable == other.durable and
                     self.auto_delete == other.auto_delete and
                     self.delivery_mode == other.delivery_mode)
-        return False
+        return NotImplemented
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
 
     def __repr__(self):
         return super(Exchange, self).__repr__(str(self))
@@ -423,11 +432,13 @@ class Queue(MaybeChannelBound):
     .. attribute:: on_declared
 
         Optional callback to be applied when the queue has been
-        declared (the ``queue_declare`` method returns).
-        This must be function with a signature that accepts at least 3
+        declared (the ``queue_declare`` operation is complete).
+        This must be a function with a signature that accepts at least 3
         positional arguments: ``(name, messages, consumers)``.
 
     """
+    ContentDisallowed = ContentDisallowed
+
     name = ''
     exchange = Exchange('')
     routing_key = ''
@@ -542,7 +553,7 @@ class Queue(MaybeChannelBound):
     def get(self, no_ack=None, accept=None):
         """Poll the server for a new message.
 
-        Returns the message instance if a message was available,
+        Must return the message if a message was available,
         or :const:`None` otherwise.
 
         :keyword no_ack: If enabled the broker will automatically
@@ -642,20 +653,20 @@ class Queue(MaybeChannelBound):
                     self.durable == other.durable and
                     self.exclusive == other.exclusive and
                     self.auto_delete == other.auto_delete)
-        return False
+        return NotImplemented
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
 
     def __repr__(self):
         s = super(Queue, self).__repr__
         if self.bindings:
-            return s('Queue %r -> %s' % (
-                self.name,
-                pretty_bindings(self.bindings),
+            return s('Queue {0.name!r} -> {bindings}'.format(
+                self, bindings=pretty_bindings(self.bindings),
             ))
-        return s('Queue %r -> %s -> %r' % (
-            self.name,
-            self.exchange,
-            self.routing_key or '',
-        ))
+        return s(
+            'Queue {0.name!r} -> {0.exchange!r} -> {0.routing_key}'.format(
+                self))
 
     @property
     def can_cache_declaration(self):
