@@ -4,10 +4,12 @@ import os
 import logging
 import sys
 
+from logging.handlers import WatchedFileHandler
+
+from .five import string_t
 from .utils import cached_property
-from .utils.compat import WatchedFileHandler
 from .utils.encoding import safe_repr, safe_str
-from .utils.functional import maybe_promise
+from .utils.functional import maybe_evaluate
 
 __all__ = ['LogMixin', 'LOG_LEVELS', 'get_loglevel', 'setup_logging']
 
@@ -24,42 +26,31 @@ class NullHandler(logging.Handler):
 
 
 def get_logger(logger):
-    if isinstance(logger, basestring):
+    if isinstance(logger, string_t):
         logger = logging.getLogger(logger)
     if not logger.handlers:
         logger.addHandler(NullHandler())
     return logger
 
 
-def anon_logger(name):
-    logger = logging.getLogger(name)
-    logger.addHandler(NullHandler())
-    return logger
-
-
 def get_loglevel(level):
-    if isinstance(level, basestring):
+    if isinstance(level, string_t):
         return LOG_LEVELS[level]
     return level
 
 
 def naive_format_parts(fmt):
-    l = fmt.split('%')
-    for i, e in enumerate(l[1:]):
-        if not e or not l[i - 1]:
-            yield
-        elif e[0] in ['r', 's']:
-            yield e[0]
+    parts = fmt.split('%')
+    for i, e in enumerate(parts[1:]):
+        yield None if not e or not parts[i - 1] else e[0]
 
 
-def safeify_format(fmt, *args):
+def safeify_format(fmt, args,
+                   filters={'s': safe_str,
+                            'r': safe_repr}):
     for index, type in enumerate(naive_format_parts(fmt)):
-        if not type:
-            yield args[index]
-        elif type == 'r':
-            yield safe_repr(args[index])
-        elif type == 's':
-            yield safe_str(args[index])
+        filt = filters.get(type)
+        yield filt(args[index]) if filt else args[index]
 
 
 class LogMixin(object):
@@ -91,11 +82,11 @@ class LogMixin(object):
     def log(self, severity, *args, **kwargs):
         if self.logger.isEnabledFor(severity):
             log = self.logger.log
-            if len(args) > 1 and isinstance(args[0], basestring):
-                expand = [maybe_promise(arg) for arg in args[1:]]
+            if len(args) > 1 and isinstance(args[0], string_t):
+                expand = [maybe_evaluate(arg) for arg in args[1:]]
                 return log(severity,
                            self.annotate(args[0].replace('%r', '%s')),
-                           *list(safeify_format(args[0], *expand)), **kwargs)
+                           *list(safeify_format(args[0], expand)), **kwargs)
             else:
                 return self.logger.log(
                     severity, self.annotate(' '.join(map(safe_str, args))),
