@@ -9,17 +9,16 @@ from __future__ import absolute_import
 
 from itertools import count
 
+from .compression import compress
 from .connection import maybe_channel, is_connection
 from .entity import Exchange, Queue, DELIVERY_MODES
-from .compression import compress
-from .serialization import encode, prepare_accept_content
+from .exceptions import ContentDisallowed
+from .five import int_types, text_t, values
+from .serialization import dumps, prepare_accept_content
 from .utils import ChannelPromise, maybe_list
 
 __all__ = ['Exchange', 'Queue', 'Producer', 'Consumer']
 
-# XXX compat attribute
-entry_to_queue = Queue.from_dict
-
 
 class Producer(object):
     """Message Producer.
@@ -82,6 +81,9 @@ class Producer(object):
         if self._channel:
             self.revive(self._channel)
 
+    def __repr__(self):
+        return '<Producer: {0.channel}>'.format(self)
+
     def __reduce__(self):
         return self.__class__, self.__reduce_args__()
 
@@ -148,7 +150,7 @@ class Producer(object):
             exchange = exchange.name
         else:
             delivery_mode = delivery_mode or self.exchange.delivery_mode
-        if not isinstance(delivery_mode, (int, long)):
+        if not isinstance(delivery_mode, int_types):
             delivery_mode = DELIVERY_MODES[delivery_mode]
         properties['delivery_mode'] = delivery_mode
 
@@ -230,11 +232,11 @@ class Producer(object):
         if not content_type:
             serializer = serializer or self.serializer
             (content_type, content_encoding,
-             body) = encode(body, serializer=serializer)
+             body) = dumps(body, serializer=serializer)
         else:
             # If the programmer doesn't want us to serialize,
             # make sure content_encoding is set.
-            if isinstance(body, unicode):
+            if isinstance(body, text_t):
                 if not content_encoding:
                     content_encoding = 'utf-8'
                 body = body.encode(content_encoding)
@@ -269,6 +271,8 @@ class Consumer(object):
     :keyword on_decode_error: see :attr:`on_decode_error`.
 
     """
+    ContentDisallowed = ContentDisallowed
+
     #: The connection/channel to use for this consumer.
     channel = None
 
@@ -331,7 +335,7 @@ class Consumer(object):
     #: in which case only json is allowed.
     accept = None
 
-    _next_tag = count(1).next   # global
+    _tags = count(1)   # global
 
     def __init__(self, channel, queues=None, no_ack=None, auto_declare=None,
                  callbacks=None, on_decode_error=None, on_message=None,
@@ -446,7 +450,7 @@ class Consumer(object):
 
         """
         cancel = self.channel.basic_cancel
-        for tag in self._active_tags.itervalues():
+        for tag in values(self._active_tags):
             cancel(tag)
         self._active_tags.clear()
     close = cancel
@@ -462,7 +466,7 @@ class Consumer(object):
             self.channel.basic_cancel(tag)
 
     def consuming_from(self, queue):
-        """Returns :const:`True` if the consumer is currently
+        """Return :const:`True` if the consumer is currently
         consuming from queue'."""
         name = queue
         if isinstance(queue, Queue):
@@ -563,7 +567,7 @@ class Consumer(object):
         return tag
 
     def _add_tag(self, queue, consumer_tag=None):
-        tag = consumer_tag or str(self._next_tag())
+        tag = consumer_tag or str(next(self._tags))
         self._active_tags[queue.name] = tag
         return tag
 
@@ -577,7 +581,7 @@ class Consumer(object):
             if accept is not None:
                 message.accept = accept
             decoded = None if on_m else message.decode()
-        except Exception, exc:
+        except Exception as exc:
             if not self.on_decode_error:
                 raise
             self.on_decode_error(message, exc)
@@ -585,7 +589,7 @@ class Consumer(object):
             return on_m(message) if on_m else self.receive(decoded, message)
 
     def __repr__(self):
-        return '<Consumer: %s>' % (self.queues, )
+        return '<Consumer: {0.queues}>'.format(self)
 
     @property
     def connection(self):
