@@ -1,24 +1,19 @@
 from __future__ import absolute_import
-from __future__ import with_statement
 
-import errno
 import pickle
 import socket
 
 from copy import copy
-from mock import patch
-from nose import SkipTest
 
 from kombu import Connection, Consumer, Producer, parse_url
 from kombu.connection import Resource
+from kombu.five import items, range
 
+from .case import Case, Mock, SkipTest, patch, skip_if_not_module
 from .mocks import Transport
-from .utils import TestCase
-
-from .utils import Mock, skip_if_not_module
 
 
-class test_connection_utils(TestCase):
+class test_connection_utils(Case):
 
     def setUp(self):
         self.url = 'amqp://user:pass@localhost:5672/my/vhost'
@@ -49,6 +44,11 @@ class test_connection_utils(TestCase):
         self.assertEqual(conn.as_uri(), self.nopass)
         self.assertEqual(conn.as_uri(include_password=True), self.url)
 
+    def test_as_uri_when_prefix(self):
+        conn = Connection('memory://')
+        conn.uri_prefix = 'foo'
+        self.assertTrue(conn.as_uri().startswith('foo+memory://'))
+
     @skip_if_not_module('pymongo')
     def test_as_uri_when_mongodb(self):
         x = Connection('mongodb://localhost')
@@ -60,7 +60,7 @@ class test_connection_utils(TestCase):
 
     def assert_info(self, conn, **fields):
         info = conn.info()
-        for field, expected in fields.iteritems():
+        for field, expected in items(fields):
             self.assertEqual(info[field], expected)
 
     def test_rabbitmq_example_urls(self):
@@ -142,7 +142,7 @@ class test_connection_utils(TestCase):
         )
 
 
-class test_Connection(TestCase):
+class test_Connection(Case):
 
     def setUp(self):
         self.conn = Connection(port=5672, transport=Transport)
@@ -169,10 +169,51 @@ class test_Connection(TestCase):
         self.assertEqual(conn2.hostname, 'foo')
         self.assertListEqual(conn2.alt, ['amqp://foo', 'amqp://bar'])
 
+    def test_collect(self):
+        connection = Connection('memory://')
+        trans = connection._transport = Mock(name='transport')
+        _collect = trans._collect = Mock(name='transport._collect')
+        _close = connection._close = Mock(name='connection._close')
+        connection.declared_entities = Mock(name='decl_entities')
+        uconn = connection._connection = Mock(name='_connection')
+        connection.collect()
+
+        self.assertFalse(_close.called)
+        _collect.assert_called_with(uconn)
+        connection.declared_entities.clear.assert_called_with()
+        self.assertIsNone(trans.client)
+        self.assertIsNone(connection._transport)
+        self.assertIsNone(connection._connection)
+
+    def test_collect_no_transport(self):
+        connection = Connection('memory://')
+        connection._transport = None
+        connection._close = Mock()
+        connection.collect()
+        connection._close.assert_called_with()
+
+        connection._close.side_effect = socket.timeout()
+        connection.collect()
+
+    def test_collect_transport_gone(self):
+        connection = Connection('memory://')
+        uconn = connection._connection = Mock(name='conn._conn')
+        trans = connection._transport = Mock(name='transport')
+        collect = trans._collect = Mock(name='transport._collect')
+
+        def se(conn):
+            connection._transport = None
+        collect.side_effect = se
+
+        connection.collect()
+        collect.assert_called_with(uconn)
+        self.assertIsNone(connection._transport)
+
     def test_uri_passthrough(self):
-        from kombu import connection as mod
-        prev, mod.URI_PASSTHROUGH = mod.URI_PASSTHROUGH, set(['foo'])
-        try:
+        transport = Mock(name='transport')
+        with patch('kombu.connection.get_transport_cls') as gtc:
+            gtc.return_value = transport
+            transport.can_parse_url = True
             with patch('kombu.connection.parse_url') as parse_url:
                 c = Connection('foo+mysql://some_host')
                 self.assertEqual(c.transport_cls, 'foo')
@@ -184,10 +225,8 @@ class test_Connection(TestCase):
                 self.assertEqual(c.transport_cls, 'foo')
                 self.assertFalse(parse_url.called)
                 self.assertEqual(c.hostname, 'mysql://some_host')
-        finally:
-            mod.URI_PASSTHROUGH = prev
-        c = Connection('amqp+sqlite://some_host')
-        self.assertTrue(c.as_uri().startswith('amqp+'))
+        c = Connection('pyamqp+sqlite://some_host')
+        self.assertTrue(c.as_uri().startswith('pyamqp+'))
 
     def test_default_ensure_callback(self):
         with patch('kombu.connection.logger') as logger:
@@ -220,32 +259,6 @@ class test_Connection(TestCase):
             self.assertEqual(cb(KeyError(), intervals, 0), 0)
             self.assertTrue(errback.called)
 
-    def test_drain_nowait(self):
-        c = Connection(transport=Mock)
-        c.drain_events = Mock()
-        c.drain_events.side_effect = socket.timeout()
-
-        c.more_to_read = True
-        self.assertFalse(c.drain_nowait())
-        self.assertFalse(c.more_to_read)
-
-        c.drain_events.side_effect = socket.error()
-        c.drain_events.side_effect.errno = errno.EAGAIN
-        c.more_to_read = True
-        self.assertFalse(c.drain_nowait())
-        self.assertFalse(c.more_to_read)
-
-        c.drain_events.side_effect = socket.error()
-        c.drain_events.side_effect.errno = errno.EPERM
-        with self.assertRaises(socket.error):
-            c.drain_nowait()
-
-        c.more_to_read = False
-        c.drain_events = Mock()
-        self.assertTrue(c.drain_nowait())
-        c.drain_events.assert_called_with(timeout=0)
-        self.assertTrue(c.more_to_read)
-
     def test_supports_heartbeats(self):
         c = Connection(transport=Mock)
         c.transport.supports_heartbeats = False
@@ -256,11 +269,13 @@ class test_Connection(TestCase):
         c.transport.supports_ev = False
         self.assertFalse(c.is_evented)
 
-    def test_eventmap(self):
+    def test_register_with_event_loop(self):
         c = Connection(transport=Mock)
-        c.transport.eventmap.return_value = {1: 1, 2: 2}
-        self.assertDictEqual(c.eventmap, {1: 1, 2: 2})
-        c.transport.eventmap.assert_called_with(c.connection)
+        loop = Mock(name='loop')
+        c.register_with_event_loop(loop)
+        c.transport.register_with_event_loop.assert_called_with(
+            c.connection, loop,
+        )
 
     def test_manager(self):
         c = Connection(transport=Mock)
@@ -270,6 +285,12 @@ class test_Connection(TestCase):
         c = Connection('amqp://example.com')
         self.assertEqual(copy(c).info(), c.info())
 
+    def test_copy_multiples(self):
+        c = Connection('amqp://A.example.com;amqp://B.example.com')
+        self.assertTrue(c.alt)
+        d = copy(c)
+        self.assertEqual(d.alt, c.alt)
+
     def test_switch(self):
         c = Connection('amqp://foo')
         c._closed = True
@@ -466,7 +487,7 @@ class test_Connection(TestCase):
         self.assertTupleEqual(conn.connection_errors, (KeyError, ValueError))
 
 
-class test_Connection_with_transport_options(TestCase):
+class test_Connection_with_transport_options(Case):
 
     transport_options = {'pool_recycler': 3600, 'echo': True}
 
@@ -485,7 +506,7 @@ class xResource(Resource):
         pass
 
 
-class ResourceCase(TestCase):
+class ResourceCase(Case):
     abstract = True
 
     def create_resource(self, limit, preload):
@@ -505,7 +526,7 @@ class ResourceCase(TestCase):
             return
         P = self.create_resource(10, 0)
         self.assertState(P, 10, 0)
-        chans = [P.acquire() for _ in xrange(10)]
+        chans = [P.acquire() for _ in range(10)]
         self.assertState(P, 0, 10)
         with self.assertRaises(P.LimitExceeded):
             P.acquire()
@@ -566,7 +587,7 @@ class ResourceCase(TestCase):
         if self.abstract:
             return
         P = self.create_resource(10, 10)
-        cr = P.close_resource = Mock()
+        cr = P.collect_resource = Mock()
         cr.side_effect = AttributeError('x')
 
         P.acquire()
@@ -609,6 +630,19 @@ class test_ConnectionPool(ResourceCase):
         self.assertIsNotNone(q[1]._connection)
         self.assertIsNone(q[2]()._connection)
 
+    def test_acquire_raises_evaluated(self):
+        P = self.create_resource(1, 0)
+        # evaluate the connection first
+        r = P.acquire()
+        r.release()
+        P.prepare = Mock()
+        P.prepare.side_effect = MemoryError()
+        P.release = Mock()
+        with self.assertRaises(MemoryError):
+            with P.acquire():
+                assert False
+        P.release.assert_called_with(r)
+
     def test_release_no__debug(self):
         P = self.create_resource(10, 2)
         R = Mock()
