@@ -1,22 +1,19 @@
-from __future__ import absolute_import
-from __future__ import with_statement
+from __future__ import absolute_import, unicode_literals
 
 import anyjson
 import pickle
 
 from collections import defaultdict
-from mock import patch
 
 from kombu import Connection, Consumer, Producer, Exchange, Queue
 from kombu.exceptions import MessageStateError
 from kombu.utils import ChannelPromise
 
+from .case import Case, Mock, patch
 from .mocks import Transport
-from .utils import TestCase
-from .utils import Mock
 
 
-class test_Producer(TestCase):
+class test_Producer(Case):
 
     def setUp(self):
         self.exchange = Exchange('foo', 'direct')
@@ -25,6 +22,10 @@ class test_Producer(TestCase):
         self.assertTrue(self.connection.connection.connected)
         self.assertFalse(self.exchange.is_bound)
 
+    def test_repr(self):
+        p = Producer(self.connection)
+        self.assertTrue(repr(p))
+
     def test_pickle(self):
         chan = Mock()
         producer = Producer(chan, serializer='pickle')
@@ -68,7 +69,7 @@ class test_Producer(TestCase):
                       'p.declare() declares exchange')
 
     def test_prepare(self):
-        message = {u'the quick brown fox': u'jumps over the lazy dog'}
+        message = {'the quick brown fox': 'jumps over the lazy dog'}
         channel = self.connection.channel()
         p = Producer(channel, self.exchange, serializer='json')
         m, ctype, cencoding = p._prepare(message, headers={})
@@ -77,7 +78,7 @@ class test_Producer(TestCase):
         self.assertEqual(cencoding, 'utf-8')
 
     def test_prepare_compression(self):
-        message = {u'the quick brown fox': u'jumps over the lazy dog'}
+        message = {'the quick brown fox': 'jumps over the lazy dog'}
         channel = self.connection.channel()
         p = Producer(channel, self.exchange, serializer='json')
         headers = {}
@@ -107,7 +108,7 @@ class test_Producer(TestCase):
         self.assertEqual(cencoding, 'alien')
 
     def test_prepare_is_already_unicode(self):
-        message = u'the quick brown fox'
+        message = 'the quick brown fox'
         channel = self.connection.channel()
         p = Producer(channel, self.exchange, serializer='json')
         m, ctype, cencoding = p._prepare(message, content_type='text/plain')
@@ -177,7 +178,7 @@ class test_Producer(TestCase):
     def test_publish(self):
         channel = self.connection.channel()
         p = Producer(channel, self.exchange, serializer='json')
-        message = {u'the quick brown fox': u'jumps over the lazy dog'}
+        message = {'the quick brown fox': 'jumps over the lazy dog'}
         ret = p.publish(message, routing_key='process')
         self.assertIn('prepare_message', channel)
         self.assertIn('basic_publish', channel)
@@ -215,7 +216,7 @@ class test_Producer(TestCase):
         self.assertTrue(p.on_return)
 
 
-class test_Consumer(TestCase):
+class test_Consumer(Case):
 
     def setUp(self):
         self.connection = Connection(transport=Transport)
@@ -223,6 +224,68 @@ class test_Consumer(TestCase):
         self.assertTrue(self.connection.connection.connected)
         self.exchange = Exchange('foo', 'direct')
 
+    def test_accept(self):
+        a = Consumer(self.connection)
+        self.assertIsNone(a.accept)
+        b = Consumer(self.connection, accept=['json', 'pickle'])
+        self.assertSetEqual(
+            b.accept,
+            set(['application/json', 'application/x-python-serialize']),
+        )
+        c = Consumer(self.connection, accept=b.accept)
+        self.assertSetEqual(b.accept, c.accept)
+
+    def test_enter_exit_cancel_raises(self):
+        c = Consumer(self.connection)
+        c.cancel = Mock(name='Consumer.cancel')
+        c.cancel.side_effect = KeyError('foo')
+        with c:
+            pass
+        c.cancel.assert_called_with()
+
+    def test_receive_callback_accept(self):
+        message = Mock(name='Message')
+        callback = Mock(name='on_message')
+        c = Consumer(self.connection, accept=['json'], on_message=callback)
+        c.channel = Mock(name='channel')
+        c.channel.message_to_python = None
+
+        c._receive_callback(message)
+        callback.assert_called_with(message)
+        self.assertSetEqual(message.accept, c.accept)
+
+    def test_accept__content_disallowed(self):
+        conn = Connection('memory://')
+        q = Queue('foo', exchange=self.exchange)
+        p = conn.Producer()
+        p.publish(
+            {'complex': object()},
+            declare=[q], exchange=self.exchange, serializer='pickle',
+        )
+
+        callback = Mock(name='callback')
+        with conn.Consumer(queues=[q], callbacks=[callback]) as consumer:
+            with self.assertRaises(consumer.ContentDisallowed):
+                conn.drain_events(timeout=1)
+        self.assertFalse(callback.called)
+
+    def test_accept__content_allowed(self):
+        conn = Connection('memory://')
+        q = Queue('foo', exchange=self.exchange)
+        p = conn.Producer()
+        p.publish(
+            {'complex': object()},
+            declare=[q], exchange=self.exchange, serializer='pickle',
+        )
+
+        callback = Mock(name='callback')
+        with conn.Consumer(queues=[q], accept=['pickle'],
+                           callbacks=[callback]):
+            conn.drain_events(timeout=1)
+        self.assertTrue(callback.called)
+        body, message = callback.call_args[0]
+        self.assertTrue(body['complex'])
+
     def test_set_no_channel(self):
         c = Consumer(None)
         self.assertIsNone(c.channel)
@@ -413,11 +476,11 @@ class test_Consumer(TestCase):
             message.payload     # trigger cache
 
         consumer.register_callback(callback)
-        consumer._receive_callback({u'foo': u'bar'})
+        consumer._receive_callback({'foo': 'bar'})
 
         self.assertIn('basic_ack', channel)
         self.assertIn('message_to_python', channel)
-        self.assertEqual(received[0], {u'foo': u'bar'})
+        self.assertEqual(received[0], {'foo': 'bar'})
 
     def test_basic_ack_twice(self):
         channel = self.connection.channel()
