@@ -1,30 +1,25 @@
 from __future__ import absolute_import
-from __future__ import with_statement
 
 import warnings
 
-from mock import patch
-
 from kombu import Connection
-from kombu.exceptions import StdChannelError
+from kombu.exceptions import ResourceError, ChannelError
 from kombu.transport import virtual
 from kombu.utils import uuid
 from kombu.compression import compress
 
-from kombu.tests.compat import catch_warnings
-from kombu.tests.utils import TestCase
-from kombu.tests.utils import Mock, redirect_stdouts
+from kombu.tests.case import Case, Mock, patch, redirect_stdouts
 
 
 def client(**kwargs):
-    return Connection(transport='kombu.transport.virtual.Transport', **kwargs)
+    return Connection(transport='kombu.transport.virtual:Transport', **kwargs)
 
 
 def memory_client():
     return Connection(transport='memory')
 
 
-class test_BrokerState(TestCase):
+class test_BrokerState(Case):
 
     def test_constructor(self):
         s = virtual.BrokerState()
@@ -36,7 +31,7 @@ class test_BrokerState(TestCase):
         self.assertEqual(t.bindings, 32)
 
 
-class test_QoS(TestCase):
+class test_QoS(Case):
 
     def setUp(self):
         self.q = virtual.QoS(client().channel(), prefetch_count=10)
@@ -67,7 +62,7 @@ class test_QoS(TestCase):
         self.q.append(i + 1, uuid())
         self.assertFalse(self.q.can_consume())
 
-        tag1 = iter(self.q._delivered).next()
+        tag1 = next(iter(self.q._delivered))
         self.q.ack(tag1)
         self.assertTrue(self.q.can_consume())
 
@@ -102,7 +97,7 @@ class test_QoS(TestCase):
         self.assertEqual(self.q.get('foo'), 1)
 
 
-class test_Message(TestCase):
+class test_Message(Case):
 
     def test_create(self):
         c = client().channel()
@@ -134,7 +129,7 @@ class test_Message(TestCase):
         self.assertFalse('compression' in dict_['headers'])
 
 
-class test_AbstractChannel(TestCase):
+class test_AbstractChannel(Case):
 
     def test_get(self):
         with self.assertRaises(NotImplementedError):
@@ -175,7 +170,7 @@ class test_AbstractChannel(TestCase):
         self.assertTrue(cycle.called)
 
 
-class test_Channel(TestCase):
+class test_Channel(Case):
 
     def setUp(self):
         self.channel = client().channel()
@@ -184,6 +179,14 @@ class test_Channel(TestCase):
         if self.channel._qos is not None:
             self.channel._qos._on_collect.cancel()
 
+    def test_exceeds_channel_max(self):
+        c = client()
+        t = c.transport
+        avail = t._avail_channel_ids = Mock(name='_avail_channel_ids')
+        avail.pop.side_effect = IndexError()
+        with self.assertRaises(ResourceError):
+            virtual.Channel(t)
+
     def test_exchange_bind_interface(self):
         with self.assertRaises(NotImplementedError):
             self.channel.exchange_bind('dest', 'src', 'key')
@@ -205,7 +208,7 @@ class test_Channel(TestCase):
     def test_exchange_declare(self):
         c = self.channel
 
-        with self.assertRaises(StdChannelError):
+        with self.assertRaises(ChannelError):
             c.exchange_declare('test_exchange_declare', 'direct',
                                durable=True, auto_delete=True, passive=True)
         c.exchange_declare('test_exchange_declare', 'direct',
@@ -380,7 +383,7 @@ class test_Channel(TestCase):
         exc = None
         try:
             raise KeyError()
-        except KeyError, exc_:
+        except KeyError as exc_:
             exc = exc_
         ru.return_value = [(exc, 1)]
 
@@ -411,7 +414,7 @@ class test_Channel(TestCase):
 
     def test_lookup__undeliverable(self, n='test_lookup__undeliverable'):
         warnings.resetwarnings()
-        with catch_warnings(record=True) as log:
+        with warnings.catch_warnings(record=True) as log:
             self.assertListEqual(
                 self.channel._lookup(n, n, 'ae.undeliver'),
                 ['ae.undeliver'],
@@ -485,11 +488,11 @@ class test_Channel(TestCase):
     def test_queue_declare_passive(self):
         has_queue = self.channel._has_queue = Mock()
         has_queue.return_value = False
-        with self.assertRaises(StdChannelError):
+        with self.assertRaises(ChannelError):
             self.channel.queue_declare(queue='21wisdjwqe', passive=True)
 
 
-class test_Transport(TestCase):
+class test_Transport(Case):
 
     def setUp(self):
         self.transport = client().transport
