@@ -23,7 +23,7 @@ from amqplib.client_0_8.channel import Channel as _Channel
 from amqplib.client_0_8.exceptions import AMQPConnectionException
 from amqplib.client_0_8.exceptions import AMQPChannelException
 
-from kombu.exceptions import StdConnectionError, StdChannelError
+from kombu.five import items
 from kombu.utils.encoding import str_to_bytes
 from kombu.utils.amq_manager import get_manager
 
@@ -55,7 +55,7 @@ class TCPTransport(transport.TCPTransport):
         while len(self._read_buffer) < n:
             try:
                 s = self.sock.recv(65536)
-            except socket.error, exc:
+            except socket.error as exc:
                 if not initial and exc.errno in (errno.EAGAIN, errno.EINTR):
                     continue
                 raise
@@ -104,7 +104,7 @@ class SSLTransport(transport.SSLTransport):
         while len(result) < n:
             try:
                 s = self.sslobj.read(n - len(result))
-            except socket.error, exc:
+            except socket.error as exc:
                 if not initial and exc.errno in (errno.EAGAIN, errno.EINTR):
                     continue
                 raise
@@ -188,7 +188,7 @@ class Connection(amqp.Connection):  # pragma: no cover
         try:
             try:
                 return self.method_reader.read_method()
-            except SSLError, exc:
+            except SSLError as exc:
                 # http://bugs.python.org/issue10272
                 if 'timed out' in str(exc):
                     raise socket.timeout()
@@ -201,7 +201,7 @@ class Connection(amqp.Connection):  # pragma: no cover
                 sock.settimeout(prev)
 
     def _wait_multiple(self, channels, allowed_methods, timeout=None):
-        for channel_id, channel in channels.iteritems():
+        for channel_id, channel in items(channels):
             method_queue = channel.method_queue
             for queued_method in method_queue:
                 method_sig = queued_method[0]
@@ -304,22 +304,20 @@ class Transport(base.Transport):
 
     # it's very annoying that amqplib sometimes raises AttributeError
     # if the connection is lost, but nothing we can do about that here.
-    connection_errors = (StdConnectionError,
-                         AMQPConnectionException,
-                         socket.error,
-                         IOError,
-                         OSError,
-                         AttributeError)
-    channel_errors = (StdChannelError, AMQPChannelException, )
+    connection_errors = (
+        base.Transport.connection_errors + (
+            AMQPConnectionException,
+            socket.error, IOError, OSError, AttributeError)
+    )
+    channel_errors = base.Transport.channel_errors + (AMQPChannelException, )
 
-    nb_keep_draining = True
-    driver_name = "amqplib"
-    driver_type = "amqp"
+    driver_name = 'amqplib'
+    driver_type = 'amqp'
     supports_ev = True
 
     def __init__(self, client, **kwargs):
         self.client = client
-        self.default_port = kwargs.get("default_port") or self.default_port
+        self.default_port = kwargs.get('default_port') or self.default_port
 
     def create_channel(self, connection):
         return connection.channel()
@@ -330,7 +328,7 @@ class Transport(base.Transport):
     def establish_connection(self):
         """Establish connection to the AMQP broker."""
         conninfo = self.client
-        for name, default_value in self.default_connection_params.items():
+        for name, default_value in items(self.default_connection_params):
             if not getattr(conninfo, name, None):
                 setattr(conninfo, name, default_value)
         if conninfo.hostname == 'localhost':
@@ -369,14 +367,9 @@ class Transport(base.Transport):
     def verify_connection(self, connection):
         return connection.channels is not None and self.is_alive(connection)
 
-    def eventmap(self, connection):
-        return {connection.method_reader.source.sock: self.client.drain_nowait}
-
-    def on_poll_init(self, poller):
-        pass
-
-    def on_poll_start(self):
-        return {}
+    def register_with_event_loop(self, connection, loop):
+        loop.add_reader(connection.method_reader.source.sock,
+                        self.on_readable, connection, loop)
 
     @property
     def default_connection_params(self):
