@@ -123,6 +123,9 @@ class Transport(object):
     def register_with_event_loop(self, loop):
         pass
 
+    def unregister_from_event_loop(self, loop):
+        pass
+
     def verify_connection(self, connection):
         return True
 
@@ -132,6 +135,8 @@ class Transport(object):
         drain_events = connection.drain_events
 
         def _read(loop):
+            if not connection.connected:
+                raise ConnectionError('Socket was disconnected')
             try:
                 drain_events(timeout=0)
             except timeout:
