@@ -481,6 +481,7 @@ class Channel(virtual.Channel):
             response = c.parse_response()
         except self.connection_errors:
             self._in_listen = False
+            raise Empty()
         if response is not None:
             payload = self._handle_message(c, response)
             if bytes_to_str(payload['type']) == 'message':
@@ -832,7 +833,7 @@ class Transport(virtual.Transport):
         return (
             (virtual.Transport.connection_errors + (
                 InconsistencyError,
-                socket.timeout,
+                socket.error,
                 exceptions.ConnectionError,
                 exceptions.AuthenticationError)),
             (virtual.Transport.channel_errors + (
