@@ -5,7 +5,7 @@ kombu.utils
 Internal utilities.
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import importlib
 import random
@@ -16,17 +16,27 @@ from itertools import count, repeat
 from time import sleep
 from uuid import UUID, uuid4 as _uuid4, _uuid_generate_random
 
-from .encoding import safe_repr as _safe_repr
+from kombu.five import int_types, items, reraise, string_t
+
+from .encoding import default_encode, safe_repr as _safe_repr
 
 try:
     import ctypes
 except:
     ctypes = None  # noqa
 
+try:
+    from io import UnsupportedOperation
+    FILENO_ERRORS = (AttributeError, ValueError, UnsupportedOperation)
+except ImportError:  # pragma: no cover
+    # Py2
+    FILENO_ERRORS = (AttributeError, ValueError)  # noqa
+
+
 __all__ = ['EqualityDict', 'say', 'uuid', 'kwdict', 'maybe_list',
            'fxrange', 'fxrangemax', 'retry_over_time',
            'emergency_dump_state', 'cached_property',
-           'reprkwargs', 'reprcall', 'nested']
+           'reprkwargs', 'reprcall', 'nested', 'fileno', 'maybe_fileno']
 
 
 def symbol_by_name(name, aliases={}, imp=None, package=None,
@@ -67,7 +77,7 @@ def symbol_by_name(name, aliases={}, imp=None, package=None,
     if imp is None:
         imp = importlib.import_module
 
-    if not isinstance(name, basestring):
+    if not isinstance(name, string_t):
         return name                                 # already a class
 
     name = aliases.get(name) or name
@@ -78,9 +88,10 @@ def symbol_by_name(name, aliases={}, imp=None, package=None,
     try:
         try:
             module = imp(module_name, package=package, **kwargs)
-        except ValueError, exc:
-            raise ValueError, ValueError(
-                "Couldn't import %r: %s" % (name, exc)), sys.exc_info()[2]
+        except ValueError as exc:
+            reraise(ValueError,
+                    ValueError("Couldn't import {0!r}: {1}".format(name, exc)),
+                    sys.exc_info()[2])
         return getattr(module, cls_name) if cls_name else module
     except (ImportError, AttributeError):
         if default is None:
@@ -110,8 +121,8 @@ class EqualityDict(dict):
         return dict.__delitem__(self, eqhash(key))
 
 
-def say(m, *s):
-    sys.stderr.write(str(m) % s + '\n')
+def say(m, *fargs, **fkwargs):
+    print(str(m).format(*fargs, **fkwargs), file=sys.stderr)
 
 
 def uuid4():
@@ -146,7 +157,7 @@ else:
 
         """
         return dict((key.encode('utf-8'), value)
-                    for key, value in kwargs.items())
+                    for key, value in items(kwargs))
 
 
 def maybe_list(v):
@@ -215,13 +226,13 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
     for retries in count():
         try:
             return fun(*args, **kwargs)
-        except catch, exc:
+        except catch as exc:
             if max_retries is not None and retries >= max_retries:
                 raise
             if callback:
                 callback()
             tts = (errback(exc, interval_range, retries) if errback
-                   else interval_range.next())
+                   else next(interval_range))
             if tts:
                 for i in range(int(tts / interval_step)):
                     if callback:
@@ -237,14 +248,14 @@ def emergency_dump_state(state, open_file=open, dump=None):
         import pickle
         dump = pickle.dump
     persist = mktemp()
-    say('EMERGENCY DUMP STATE TO FILE -> %s <-' % persist)
+    say('EMERGENCY DUMP STATE TO FILE -> {0} <-', persist)
     fh = open_file(persist, 'w')
     try:
         try:
             dump(state, fh, protocol=0)
-        except Exception, exc:
-            say('Cannot pickle state: %r. Fallback to pformat.' % (exc, ))
-            fh.write(pformat(state))
+        except Exception as exc:
+            say('Cannot pickle state: {0!r}. Fallback to pformat.', exc)
+            fh.write(default_encode(pformat(state)))
     finally:
         fh.flush()
         fh.close()
@@ -273,7 +284,7 @@ class cached_property(object):
         def connection(self, value):
             # Additional action to do at del(self.attr)
             if value is not None:
-                print('Connection %r deleted' % (value, ))
+                print('Connection {0!r} deleted'.format(value)
 
     """
 
@@ -319,14 +330,16 @@ class cached_property(object):
         return self.__class__(self.__get, self.__set, fdel)
 
 
-def reprkwargs(kwargs, sep=', ', fmt='%s=%s'):
-    return sep.join(fmt % (k, _safe_repr(v)) for k, v in kwargs.iteritems())
+def reprkwargs(kwargs, sep=', ', fmt='{0}={1}'):
+    return sep.join(fmt.format(k, _safe_repr(v)) for k, v in items(kwargs))
 
 
 def reprcall(name, args=(), kwargs={}, sep=', '):
-    return '%s(%s%s%s)' % (name, sep.join(map(_safe_repr, args or ())),
-                           (args and kwargs) and sep or '',
-                           reprkwargs(kwargs, sep))
+    return '{0}({1}{2}{3})'.format(
+        name, sep.join(map(_safe_repr, args or ())),
+        (args and kwargs) and sep or '',
+        reprkwargs(kwargs, sep),
+    )
 
 
 @contextmanager
@@ -359,7 +372,7 @@ def nested(*managers):  # pragma: no cover
                 # Don't rely on sys.exc_info() still containing
                 # the right information. Another exception may
                 # have been raised and caught by an exit method
-                raise exc[0], exc[1], exc[2]
+                reraise(exc[0], exc[1], exc[2])
     finally:
         del(exc)
 
@@ -401,3 +414,17 @@ def escape_regex(p, white=''):
     return ''.join(c if c.isalnum() or c in white
                    else ('\\000' if c == '\000' else '\\' + c)
                    for c in p)
+
+
+def fileno(f):
+    if isinstance(f, int_types):
+        return f
+    return f.fileno()
+
+
+def maybe_fileno(f):
+    """Get object fileno, or :const:`None` if not defined."""
+    try:
+        return fileno(f)
+    except FILENO_ERRORS:
+        pass
